JupyterLab Pioneer
===================

A JupyterLab extension for generating and exporting JupyterLab event telemetry data.

Using this extension
---------------------

:doc:`quick_start` 
   Set up JupyterLab Pioneer with docker.
   
:doc:`installation`
   How to install the extension package and configure manually.

:doc:`configuration`
   How to use the configuration file to control the activated events and data exporters of the extension.

:doc:`event_library`
   A list of all the events that can be activated by the extension.

Development
---------------------

:doc:`architecture`
   Architecture diagram

:doc:`custom_event`
   How to implement a custom event extension

:doc:`contributing`
   How to contribute to the extension


.. Hidden TOCs

.. toctree::
   :maxdepth: 1
   :numbered:
   :caption: Using this extension
   :hidden:

   quick_start
   installation
   configuration
   event_library

.. toctree::
   :maxdepth: 1
   :numbered:
   :caption: Development
   :hidden:

   architecture
   custom_event
   contributing

.. toctree::
   :caption: Reference:
   :hidden:

   jupyterlab_pioneer
